@@ -1,12 +1,9 @@
 """Animation scrollbar handling."""
 import datetime
-try:
-    import json  # Python 2.6+
-except ImportError:
-    import simplejson as json  # Python 2.5-
 
-from django.http import HttpResponse
 from django.http import Http404
+from django.http import HttpResponse
+from django.utils import simplejson as json
 
 from lizard_map.daterange import current_start_end_dates
 from lizard_map.daterange import DUTCH_DATE_FORMAT
@@ -77,6 +74,7 @@ class AnimationSettings(object):
 
     def _get_slider_position(self):
         """Return value stored in the session."""
-        return self.request.session[ANIMATION_SETTINGS].get('slider_position', 0)
+        return self.request.session[ANIMATION_SETTINGS].get(
+            'slider_position', 0)
 
     slider_position = property(_get_slider_position, _set_slider_position)
