@@ -1,7 +1,8 @@
 // jslint configuration; btw: don't put a space before 'jslint' below.
 /*jslint browser: true */
 /*global $, OpenLayers, window, updateLayer, updateLayers,
-stretchOneSidebarBox, reloadGraphs, fillSidebar, show_popup */
+stretchOneSidebarBox, reloadGraphs, fillSidebar, show_popup,
+hover_popup */
 
 var animationTimer;
 
@@ -170,15 +171,33 @@ function setUpGraphEditPopup() {
 
 /*
 Shows legend tooltip. Re-initializes after workspace update.
-TODO: show tooltip when mouseover for the first time */
-function setUpLegendTooltip() {
-    $(".legend-tooltip").live('mouseover', function () {
-        if (!$(".legend-tooltip").data("popup-initialized")) {
-            $(".legend-tooltip").data("popup-initialized", true);
-            $(".legend-tooltip").tooltip({
+*/
+function setUpLegendTooltips() {
+    $(".legend-tooltip").each(function () {
+        if (!$(this).data("popup-initialized")) {
+            $(this).data("popup-initialized", true);
+            $(this).tooltip({
                 position: 'center right',
                 effect: 'fade',
-                offset: [0, 10]
+                offset: [0, 10],
+                onShow: function () {
+                    var offset, pixels_below_screen;
+                    // Too high?
+                    offset = this.getTip().offset();
+                    if (offset.top < 0) {
+                        offset.top = 0;
+                        this.getTip().offset(offset);
+                    }
+                    // Too low?
+                    pixels_below_screen = offset.top +
+                        this.getTip().height() -
+                        $(window).height();
+                    if (pixels_below_screen > 0) {
+                        offset.top = offset.top - pixels_below_screen;
+                        this.getTip().offset(offset);
+                    }
+                    // Repositioning beforehand would be visually nicer.
+                }
             });
         }
     });
@@ -210,11 +229,6 @@ function setUpEmptyTempInteraction() {
 }
 
 
-// Commented out: lizard-ui now has generic support for it (see the
-// in-browser documentation).
-// function loadSizedImages() {
-
-
 function popup_click_handler(x, y, map) {
     var extent, radius, url;
     extent = map.getExtent();
@@ -234,6 +248,24 @@ function popup_click_handler(x, y, map) {
 }
 
 
+function popup_hover_handler(x, y, map) {
+    /* Show name of one item when hovering above a map */
+    var extent, radius, url;
+    extent = map.getExtent();
+    radius = Math.abs(extent.top - extent.bottom) / 30;  // experimental, seems to work good
+    url = $(".workspace").attr("data-url-lizard-map-search-name");
+    if (url !== undefined) {
+        $.getJSON(
+            url,
+            { x: x, y: y, radius: radius },
+            function (data) {
+                hover_popup(data, map);
+            }
+        );
+    }
+}
+
+
 // Initialize all workspace actions.
 $(document).ready(function () {
     setUpWorkspaceAcceptable();
@@ -243,7 +275,7 @@ $(document).ready(function () {
     setUpEmptyTempInteraction();
     setUpAnimationSlider();
     setUpGraphEditPopup();
-    setUpLegendTooltip();
+    setUpLegendTooltips();
 
     /* Workspace functions, requires jquery.workspace.js */
     $(".workspace").workspaceInteraction();
