@@ -13,6 +13,7 @@ import mapnik
 
 from lizard_map import coordinates
 from lizard_map.adapter import parse_identifier_json
+from lizard_map.animation import AnimationSettings
 from lizard_map.daterange import current_start_end_dates
 from lizard_map.daterange import DateRangeForm
 from lizard_map.models import Workspace
@@ -28,18 +29,31 @@ from lizard_map.workspace import WorkspaceManager
 def workspace(request,
               workspace_id,
               javascript_click_handler='popup_click_handler',
+              javascript_hover_handler='popup_hover_handler',
               template='lizard_map/workspace.html'):
     """Render page with one workspace.
 
     workspaces in dictionary, because of ... ?
     """
     workspace = get_object_or_404(Workspace, pk=workspace_id)
+
+    # Calculate whether we want animation.
+    # TODO: make custom RequestContext where this code is included
+    animation_slider = False
+    for workspace_item in workspace.workspace_items.filter(
+        visible=True):
+        if workspace_item.adapter.is_animatable:
+            animation_slider = AnimationSettings(request).info()
+            break
+
     date_range_form = DateRangeForm(
         current_start_end_dates(request, for_form=True))
     return render_to_response(
         template,
         {'workspaces': {'user': [workspace]},
          'javascript_click_handler': javascript_click_handler,
+         'javascript_hover_handler': javascript_hover_handler,
+         'animation_slider': animation_slider,
          'date_range_form': date_range_form},
         context_instance=RequestContext(request))
 
@@ -162,8 +176,9 @@ def snippet_group_graph_edit(request, snippet_group_id):
 
 
 def snippet_group_image(request, snippet_group_id, legend=True):
-    """Draws a single image for the snippet_group. The MUST be at
+    """Draws a single image for the snippet_group. There MUST be at
     least 1 snippet in the group."""
+
     snippet_group = WorkspaceCollageSnippetGroup.objects.get(
         pk=snippet_group_id)
     snippets = snippet_group.snippets.all()
@@ -197,10 +212,31 @@ def snippet_group_image(request, snippet_group_id, legend=True):
 
     workspace_item = snippets[0].workspace_item
     start_date, end_date = current_start_end_dates(request)
+    layout_extra = snippet_group.layout()  # Basic extra's, x-min, title, ...
+
+    # Add current position of slider, if available
+    workspace_manager = WorkspaceManager(request)
+    workspace_groups = workspace_manager.load_or_create()
+
+    for workspaces in workspace_groups.values():
+        for workspace in workspaces:
+            for workspace_item in workspace.workspace_items.filter(
+                visible=True):
+                if workspace_item.adapter.is_animatable:
+                    animation_info = AnimationSettings(request).info()
+                    if not 'vertical_lines' in layout_extra:
+                        layout_extra['vertical_lines'] = []
+                    vertical_line = {'name': 'Positie slider',
+                                     'value': animation_info['selected_date'],
+                                     'style': {'linewidth': 3,
+                                               'linestyle': '--',
+                                               'color': 'green'}}
+                    layout_extra['vertical_lines'].append(vertical_line)
+
     return workspace_item.adapter.image(identifiers,
                                         start_date, end_date,
                                         width, height,
-                                        layout_extra=snippet_group.layout())
+                                        layout_extra=layout_extra)
 
 
 @never_cache
@@ -594,8 +630,12 @@ def search_name(request):
         result = {}
         result['name'] = found[0]['name']
         x, y = found[0]['google_coords']
-        result['x'] = x
-        result['y'] = y
+        # result['x'] = x
+        # result['y'] = y
+        # For the x/y we use the original x/y value to position the popup to
+        # the lower right of the cursor to prevent click propagation problems.
+        result['x'] = google_x + (google_radius / 10)
+        result['y'] = google_y - (google_radius / 10)
         return HttpResponse(json.dumps(result))
     else:
         return popup_json([])
@@ -689,7 +729,8 @@ def export_identifier_csv(request, workspace_item_id=None,
     start_date, end_date = current_start_end_dates(request)
     adapter = workspace_item.adapter
     values = adapter.values(identifier, start_date, end_date)
-    filename = '%s.csv' % (adapter.location(**identifier).get('name', 'export'))
+    filename = '%s.csv' % (
+        adapter.location(**identifier).get('name', 'export'))
 
     # Make the csv output.
     response = HttpResponse(mimetype='text/csv')
